#!/bin/sh -e

# We MUST have a KERNELSRC environment variable

if [ "$KERNELSRC" = "" ]; then
	echo "$0: ERROR: Please specify your kernel directory"
	exit 1
fi

echo "*** Using kernel ${KERNELSRC} for building"

if [ ! -e ${KERNELSRC}/vmlinux ]; then
	echo "$0: ERROR: Please config and build your kernel first"
	exit 1
fi



case "$1" in
at4x0a)
	CROSS_TARGET="arm-${PLATFORM}-linux-gnueabi"
	PLATFORM=$1
	;;
titan2)
	CROSS_TARGET="arm-none-linux-gnueabi"
	PLATFORM=$1
	;;
s3c64xx)
	CROSS_TARGET="arm-none-linux-gnueabi"
	PLATFORM=$1
	;;
bcm4760)
	CROSS_TARGET="arm-none-linux-gnueabi"
	PLATFORM=$1
	;;
qemu-arm)
	CROSS_TARGET="arm-none-linux-gnueabi"
	export CFLAGS="-mcpu=arm920t"
	PLATFORM=$1
	;;
*)
	echo "$0: ERROR: Unknown platform \"$1\"."
	exit 1
	;;
esac

PROGNAME="apmd"
SRCDIR="${PWD}"

OBJDIR="${PWD}/obj-${PLATFORM}"
INSDIR="${PWD}/ins-${PLATFORM}"

export CROSS_COMPILE="${CROSS_TARGET}-"

echo "**** Building ${PROGNAME} for ${PLATFORM}..."
make

echo "**** Installing ${PROGNAME} for ${PLATFORM}..."
make DESTDIR="${INSDIR}" install

echo "**** Successfully built & installed ${PROGNAME} for ${PLATFORM}:"
ls -l "${INSDIR}/lib"

# EOF
